@@ -2,6 +2,9 @@ package App::diff2vba;
 use v5.14;
 use warnings;
 
+use Exporter qw(import);
+our @EXPORT = qw(split_string);
+
 sub split_string {
     local $_ = shift;
     my $count = shift;
